@@ -9,16 +9,20 @@ sub new {
 }
 
 ### (partial) fitness function, sum of differ between antigens and antibodies
-sub fitness_M0 ($antibody_genome, @args)
+sub fitness_M0 ($antibody_genome, @args) {
 	my $sum = 0;
 	my $antigen_genome = @args[0];
 
-	for (my $i = 0; $i < scalar $antigen_genome->{genes}; $i++) {
-		if ($antigen_genome->{genes}[$i] == $antibody_genome->{genes}[$i]) {
+	my $genome = $antibody_genome->genome_complement($antigen_genome);
+
+	### FIXME use count perlism
+	for (my $i = 0; $i < scalar $genome->{genes}; $i++) {
+		if ($genome->{genes}[$i]) {
 			$sum ++;
 		}	
 	}	
 	
 	return $sum;
 }
+
 1;
