@@ -9,15 +9,14 @@ sub new {
 }
 
 sub fittest {
-	my ($self) = @_;
+	my ($self, @args) = @_; ### args contains a genome
 	my $fitness = 0.0;
 	my $fittest_genome = undef;
 
 	my $metafunction = Evo::Immune::MetaFunction->new(&fitness_M0);
 
 	for (my $i = 0; $i < scalar $self->{population}; $i++) {
-		my @args = ();
-		my $f = $metafunction->do($self, @args);
+		my $f = $metafunction->do($self->{population}[$i], @args);
 
 		if ($f > $fitness) {
 			$fitness = $f;
